:mod:`pyramid_nacl_session`
===========================

This Pyramid add-on defines an encrypting, pickle-based cookie serializer,
 using ``PyNaCl`` [1] to generate the symmetric encryption for the cookie state.

[1] https://pynacl.readthedocs.io/en/latest/secret/

Contents:

.. toctree::
    :maxdepth: 2

    usage
    api
    changes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
